Crate kcr_apps_redhat_com

Crate kcr_apps_redhat_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the apps.redhat.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

apps.redhat.com/v1alpha1

  • ClusterImpairment

Modules

v1alpha1